@@ -1,9 +1,13 @@
 package main
 
-import nuclei "github.com/projectdiscovery/nuclei/v3/lib"
+import (
+	"context"
+
+	nuclei "github.com/projectdiscovery/nuclei/v3/lib"
+)
 
 func main() {
-	ne, err := nuclei.NewNucleiEngine(
+	ne, err := nuclei.NewNucleiEngineCtx(context.Background(),
 		nuclei.WithTemplateFilters(nuclei.TemplateFilters{Tags: []string{"oast"}}),
 		nuclei.EnableStatsWithOpts(nuclei.StatsOptions{MetricServerPort: 6064}), // optionally enable metrics server for better observability
 	)
