@@ -5,9 +5,17 @@ import (
 	urlutil "github.com/projectdiscovery/utils/url"
 )
 
-func getScanDashBoardURL(id string) string {
+func getScanDashBoardURL(id string, teamID string) string {
 	ux, _ := urlutil.Parse(pdcpauth.DashBoardURL)
 	ux.Path = "/scans/" + id
+	if ux.Params == nil {
+		ux.Params = urlutil.NewOrderedParams()
+	}
+	if teamID != "" {
+		ux.Params.Add("team_id", teamID)
+	} else {
+		ux.Params.Add("team_id", NoneTeamID)
+	}
 	ux.Update()
 	return ux.String()
 }
