@@ -237,7 +237,9 @@ func (store *Store) ReadTemplateFromURI(uri string, remote bool) ([]byte, error)
 		if err != nil {
 			return nil, err
 		}
-		defer resp.Body.Close()
+		defer func() {
+          _ = resp.Body.Close()
+        }()
 		return io.ReadAll(resp.Body)
 	} else {
 		return os.ReadFile(uri)
