@@ -46,7 +46,9 @@ func isPoP3(host string, port int) (IsPOP3Response, error) {
 	if err != nil {
 		return resp, err
 	}
-	defer conn.Close()
+	defer func() {
+		_ = conn.Close()
+	}()
 
 	pop3Plugin := pop3.POP3Plugin{}
 	service, err := pop3Plugin.Run(conn, timeout, plugins.Target{Host: host})
