@@ -384,7 +384,9 @@ func (i *Integration) doGraphqlRequest(ctx context.Context, query string, v any,
 	if err != nil {
 		return err
 	}
-	defer resp.Body.Close()
+	defer func() {
+         _ = resp.Body.Close()
+       }()
 	if resp.StatusCode != http.StatusOK {
 		body, _ := io.ReadAll(resp.Body)
 		return fmt.Errorf("non-200 OK status code: %v body: %q", resp.Status, body)
